@@ -1,12 +1,14 @@
 import inspect
 from functools import wraps
 from inspect import getattr_static
-from typing import Any, Callable, Dict, List, Type
+from typing import Any, Callable, Dict, List, Type, TypeVar, cast
 
 from cognite.tracing import span
 
+T = TypeVar("T", bound=Callable)
 
-def traced(f: Callable) -> Callable:
+
+def traced(f: T) -> T:
     """Decorator for enabling tracing of this function"""
     if inspect.iscoroutinefunction(f):
 
@@ -24,7 +26,7 @@ def traced(f: Callable) -> Callable:
                 result = f(*args, **kwargs)
                 return result
 
-    return decorated
+    return cast(T, decorated)
 
 
 def traced_methods(cls: Type) -> Type:
